@@ -4,7 +4,7 @@
 
 use std::{
     path::{Path, PathBuf},
-    str::FromStr,
+    rc::Rc,
 };
 
 use anyhow::{anyhow, Result};
@@ -14,16 +14,15 @@ use indexmap::IndexSet;
 use crate::{
     argset,
     color::get_color_stdout,
-    commit::{CommitMessage, RepositoryCommitExtended},
+    ext::{CommitExtended, RepositoryExtended, SignatureExtended},
     hook::run_pre_commit_hook,
-    patchedit,
-    patchname::PatchName,
-    signature::SignatureExtended,
-    stack::{Error, InitializationPolicy, Stack, StackAccess, StackStateAccess},
+    patch::{patchedit, LocationConstraint, PatchLocator, PatchName},
+    stack::{InitializationPolicy, Stack, StackAccess, StackStateAccess},
     stupid::{
-        status::{Status, StatusEntryKind, StatusOptions, Statuses},
+        status::{Status, StatusOptions, Statuses},
         Stupid, StupidContext,
     },
+    wrap::Message,
 };
 
 pub(super) const STGIT_COMMAND: super::StGitCommand = super::StGitCommand {
@@ -113,7 +112,8 @@ fn make() -> clap::Command {
                 .num_args(1)
                 .value_name("patch")
                 .value_hint(ValueHint::Other)
-                .value_parser(PatchName::from_str),
+                .allow_hyphen_values(true)
+                .value_parser(clap::value_parser!(PatchLocator)),
         )
         .arg(
             Arg::new("annotate")
@@ -127,7 +127,6 @@ fn make() -> clap::Command {
         .arg(
             Arg::new("submodules")
                 .long("submodules")
-                .short('s')
                 .help("Include submodules in patch content")
                 .action(clap::ArgAction::SetTrue)
                 .conflicts_with("update"),
@@ -157,28 +156,25 @@ fn run(matches: &ArgMatches) -> Result<()> {
         ));
     }
 
-    let repo = git2::Repository::open_from_env()?;
-    let stack = Stack::from_branch(&repo, None, InitializationPolicy::AllowUninitialized)?;
-    let config = repo.config()?;
+    let repo = gix::Repository::open()?;
+    let stack = Stack::current(&repo, InitializationPolicy::AllowUninitialized)?;
+    let config = repo.config_snapshot();
     let allow_push_conflicts = argset::resolve_allow_push_conflicts(&config, matches);
 
     stack.check_head_top_mismatch()?;
 
-    let patchname = if let Some(patchname) = matches.get_one::<PatchName>("patch") {
-        if stack.has_patch(patchname) {
-            patchname.clone()
-        } else {
-            return Err(anyhow!("Patch `{patchname}` does not exist"));
-        }
+    let patchname = if let Some(patch_loc) = matches.get_one::<PatchLocator>("patch") {
+        patch_loc
+            .resolve_name(&stack)?
+            .constrain(&stack, LocationConstraint::Visible)?
     } else if let Some(top_patchname) = stack.applied().last() {
         top_patchname.clone()
     } else {
-        return Err(Error::NoAppliedPatches.into());
+        return Err(super::Error::NoAppliedPatches.into());
     };
 
     let tree_id = assemble_refresh_tree(
         &stack,
-        &config,
         matches,
         matches.get_flag("update").then_some(&patchname),
     )?;
@@ -188,11 +184,11 @@ fn run(matches: &ArgMatches) -> Result<()> {
 
     // Make temp patch
     let temp_commit_id = stack.repo.commit_ex(
-        &git2::Signature::make_author(Some(&config), matches)?,
-        &git2::Signature::default_committer(Some(&config))?,
-        &CommitMessage::from(format!("Refresh of {patchname}")),
+        &repo.get_author()?.override_author(matches),
+        repo.get_committer()?,
+        &Message::from(format!("Refresh of {patchname}")),
         tree_id,
-        [stack.get_branch_head().id()],
+        [stack.get_branch_head().id],
     )?;
 
     let temp_patchname = {
@@ -238,7 +234,7 @@ fn run(matches: &ArgMatches) -> Result<()> {
                 let (new_patchname, new_commit_id) = match patchedit::EditBuilder::default()
                     .original_patchname(Some(&patchname))
                     .existing_patch_commit(trans.get_patch_commit(&patchname))
-                    .override_tree_id(temp_commit.tree_id())
+                    .override_tree_id(temp_commit.tree_id()?.detach())
                     .allow_diff_edit(false)
                     .allow_implicit_edit(false)
                     .allow_template_save(false)
@@ -282,9 +278,9 @@ fn run(matches: &ArgMatches) -> Result<()> {
 
                 let patch_commit = trans.get_patch_commit(&patchname);
                 let temp_commit = trans.get_patch_commit(&temp_patchname);
-                let base = temp_commit.parent(0)?.tree_id();
-                let ours = patch_commit.tree_id();
-                let theirs = temp_commit.tree_id();
+                let base = temp_commit.get_parent_commit()?.tree_id()?.detach();
+                let ours = patch_commit.tree_id()?.detach();
+                let theirs = temp_commit.tree_id()?.detach();
 
                 if let Some(tree_id) = repo.stupid().with_temp_index(|stupid_temp| {
                     stupid_temp.read_tree(ours)?;
@@ -347,13 +343,14 @@ fn run(matches: &ArgMatches) -> Result<()> {
 fn determine_refresh_paths(
     stupid: &StupidContext,
     statuses: &Statuses,
-    patch_commit: Option<&git2::Commit>,
+    patch_commit: Option<&Rc<gix::Commit>>,
     force: bool,
 ) -> Result<IndexSet<PathBuf>> {
     let refresh_paths: IndexSet<&Path> = if let Some(patch_commit) = patch_commit {
         // Restrict update to the paths that were already part of the patch.
-        let parent_tree_id = patch_commit.parent(0)?.tree_id();
-        let diff_files = stupid.diff_tree_files(parent_tree_id, patch_commit.tree_id())?;
+        let parent_tree_id = patch_commit.get_parent_commit()?.tree_id()?.detach();
+        let diff_files =
+            stupid.diff_tree_files(parent_tree_id, patch_commit.tree_id()?.detach())?;
         let patch_paths = diff_files.iter().collect::<IndexSet<_>>();
 
         statuses
@@ -372,11 +369,7 @@ fn determine_refresh_paths(
     };
 
     // Ensure no conflicts in the files to be refreshed.
-    if statuses.iter().any(|entry| {
-        matches!(entry.kind(), StatusEntryKind::Unmerged) && refresh_paths.contains(entry.path())
-    }) {
-        return Err(Error::OutstandingConflicts.into());
-    }
+    statuses.check_conflicts_filter(|entry| refresh_paths.contains(entry.path()))?;
 
     // Ensure worktree and index states are valid for the given options.
     // Forcing means changes will be taken from both the index and worktree.
@@ -394,7 +387,7 @@ fn determine_refresh_paths(
             }
             if !is_index_clean && !is_worktree_clean {
                 return Err(anyhow!(
-                    "The index is dirty; consider using `--index` or `--force`",
+                    "the index is dirty; consider using `--index` or `--force`",
                 ));
             }
         }
@@ -412,14 +405,14 @@ fn write_tree(
     stack: &Stack,
     refresh_paths: &IndexSet<PathBuf>,
     is_path_limiting: bool,
-) -> Result<git2::Oid> {
+) -> Result<gix::ObjectId> {
     // N.B. using temp index is necessary for the cases where there are conflicts in the
     // default index. I.e. by using a temp index, a subset of paths without conflicts
     // may be formed into a coherent tree while leaving the default index as-is.
     let stupid = stack.repo.stupid();
     if is_path_limiting {
         let tree_id_result = stupid.with_temp_index(|stupid_temp| {
-            stupid_temp.read_tree(stack.get_branch_head().tree_id())?;
+            stupid_temp.read_tree(stack.get_branch_head().tree_id()?.detach())?;
             stupid_temp.update_index(Some(refresh_paths))?;
             stupid_temp.write_tree()
         });
@@ -435,10 +428,9 @@ fn write_tree(
 
 pub(crate) fn assemble_refresh_tree(
     stack: &Stack,
-    config: &git2::Config,
     matches: &ArgMatches,
     limit_to_patchname: Option<&PatchName>,
-) -> Result<git2::Oid> {
+) -> Result<gix::ObjectId> {
     let stupid = stack.repo.stupid();
     let opt_pathspecs = matches.get_many::<PathBuf>("pathspecs");
     let is_path_limiting = limit_to_patchname.is_some() || opt_pathspecs.is_some();
@@ -453,7 +445,11 @@ pub(crate) fn assemble_refresh_tree(
         let submodules_flag = matches.get_flag("submodules");
         let nosubmodules_flag = matches.get_flag("no-submodules");
         let use_submodules = if !submodules_flag && !nosubmodules_flag {
-            config.get_bool("stgit.refreshsubmodules").unwrap_or(false)
+            stack
+                .repo
+                .config_snapshot()
+                .boolean("stgit.refreshsubmodules")
+                .unwrap_or(false)
         } else {
             submodules_flag
         };
@@ -476,7 +472,7 @@ pub(crate) fn assemble_refresh_tree(
 
     let tree_id = if matches.get_flag("no-verify")
         || !run_pre_commit_hook(stack.repo, matches.get_flag("edit"))?
-        || stupid.diff_index_quiet(tree_id)?
+        || !stupid.diff_index_quiet(tree_id)?
     {
         tree_id
     } else {
