@@ -1,14 +1,15 @@
 #!/bin/sh
+
 test_description='Test the push command from a subdirectory'
+
 . ./test-lib.sh
-stg init
 
 test_expect_success 'Create some patches' '
     mkdir foo
     for i in 0 1 2; do
         stg new p$i -m p$i &&
-        echo x$i >> x.txt &&
-        echo y$i >> foo/y.txt &&
+        echo x$i >>x.txt &&
+        echo y$i >>foo/y.txt &&
         stg add x.txt foo/y.txt &&
         stg refresh
     done &&
@@ -32,7 +33,7 @@ test_expect_success 'Modifying push from a subdir' '
     [ "$(echo $(cat x.txt))" = "x0 x1" ] &&
     [ "$(echo $(cat foo/y.txt))" = "y0 y1" ] &&
     stg new extra -m extra &&
-    echo extra >> extra.txt &&
+    echo extra >>extra.txt &&
     stg add extra.txt &&
     stg refresh &&
     cd foo &&
@@ -56,14 +57,38 @@ test_expect_success 'Conflicting add/unknown file in subdir' '
     stg reset --hard &&
     stg new foo -m foo &&
     mkdir d &&
-    echo foo > d/test &&
+    echo foo >d/test &&
     stg add d/test &&
     stg refresh &&
     stg pop &&
     mkdir -p d &&
-    echo bar > d/test &&
+    echo bar >d/test &&
     command_error stg push foo &&
     [ "$(stg top)" != "foo" ]
 '
 
+test_expect_success 'Push removes current subdir' '
+   mkdir remdir &&
+   touch remdir/x.txt &&
+   stg add remdir/x.txt &&
+   stg new -m add-remdir &&
+   stg refresh &&
+   stg rm remdir/x.txt &&
+   stg new -m rm-remdir &&
+   stg refresh &&
+   stg pop &&
+   (
+       cd remdir &&
+       stg push rm-remdir
+   )
+'
+
+test_expect_success 'Pop removes current subdir' '
+    stg goto add-remdir &&
+    (
+        cd remdir &&
+        stg pop add-remdir
+    )
+'
+
 test_done
