@@ -36,22 +36,22 @@ test_expect_success 'Commit the patches' '
 
 test_expect_success 'Invalid --to and --number arguments' '
     general_error stg uncommit --to HEAD^ --number 1 2>err &&
-    grep -e "error: The argument .--to <committish>. cannot be used with .--number <number>." err
+    grep -e "error: the argument .--to <committish>. cannot be used with .--number <number>." err
 '
 
 test_expect_success 'Invalid --to with patch args' '
     general_error stg uncommit --to HEAD^ p0 2>err &&
-    grep -e "error: The argument .--to <committish>. cannot be used with .\[patchname\]\.\.\.." err
+    grep -e "error: the argument .--to <committish>. cannot be used with .\[patchname\]\.\.\.." err
 '
 
 test_expect_success 'Invalid --number' '
     general_error stg uncommit --number -1 2>err &&
-    grep -e "Invalid value .-1. for .--number <number>.: .-1. is not a positive integer" err
+    grep -e "invalid value .-1. for .--number <number>.: .-1. is not a positive integer" err
 '
 
 test_expect_success 'Too many patch names with --number' '
     command_error stg uncommit --number 2 p0 p1 2>err &&
-    grep -e "When using \`--number\`, specify at most one patch name" err
+    grep -e "when using \`--number\`, specify at most one patch name" err
 '
 
 test_expect_success 'Uncommit the patches using names' '
@@ -95,13 +95,13 @@ test_expect_success 'Attempt to reuse patch name' '
     stg uncommit &&
     [ "$(echo $(stg series --applied --noprefix))" = "bar-patch" ] &&
     command_error stg uncommit bar-patch 2>err &&
-    grep -e "Patch \`bar-patch\` already exists" err &&
+    grep -e "patch \`bar-patch\` already exists" err &&
     stg commit --all
 '
 
 test_expect_success 'Attempt to use invalid patch name' '
     general_error stg uncommit bad..patchname 2>err &&
-    grep -e "error: Invalid value .bad\.\.patchname. for .\[patchname\]\.\.\.." err
+    grep -e "error: invalid value .bad\.\.patchname. for .\[patchname\]\.\.\.." err
 '
 
 test_expect_success 'Uncommit a commit with not precisely one parent' '
@@ -122,7 +122,7 @@ test_expect_success 'Uncommit when top != head' '
 
 test_expect_success 'Uncommit to something that does not resolve to a commit' '
     command_error stg uncommit --to HEAD^{tree} 2>err &&
-    grep -e "error: Target \`HEAD^{tree}\` does not resolve to a commit" err
+    grep -e "error: target \`HEAD^{tree}\` does not resolve to a commit" err
 '
 
 test_expect_success 'Uncommit to an annotated tag' '
